from distutils.core import setup
setup(
  name='judicious',
  packages=['judicious'],
  version='0.1.0',
  description='judicious',
  author='Jordan Suchow',
  author_email='jwsuchow@gmail.com',
  url='https://suchow.com/',
)
